meta library

Constants

visibleForTemplate → const _VisibleForTemplate
Used to annotate a class, field, or method that is public for template use.

Functions

castCallback1ForDirective<T, A>(T callback(A)) → T Function(dynamic)
Wraps an typed callback with a single parameter of type A.