OnChanges class abstract

Implement this interface to get notified when any data-bound property of your directive changes.

ngOnChanges is called right before ngOnInit and whenever any data-bound input properties change.

WARNING: It is invalid to implement both DoCheck and OnChanges or AfterChanges. ngOnChanges and ngAfterChanges will never be called, as ngDoCheck is used instead of the default change detector.

Constructors

OnChanges()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

ngOnChanges() → void
Executed whenever any data-bound input properties change.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited