SafeHtml class Security

Represents HTML content that has been marked as trusted and should bypass sanitization when used with [innerHtml] bindings.

Use SafeHtml.trusted to create an instance from a trusted HTML string.

Constructors

SafeHtml.trusted(String html)
Creates a SafeHtml instance from html that will bypass sanitization.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
Returns the HTML string.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited