Pipes topic
Built-in pipes for transforming values in templates.
Pipes allow you to transform data directly in template expressions using
the | syntax, e.g. {{ birthday | date }}.
Classes
- AsyncPipe Pipes
-
An
asyncpipe awaits for a value from a Future or Stream. When a value is received, theasyncpipe marks the component to be checked for changes. - CurrencyPipe Pipes
- WARNING: this pipe uses the Internationalization API. Therefore it is only reliable in Chrome and Opera browsers.
- DatePipe Pipes
- Formats a date value to a string based on the requested format.
- DecimalPipe Pipes
- WARNING: this pipe uses the Internationalization API. Therefore it is only reliable in Chrome and Opera browsers.
- LowerCasePipe Pipes
- Transforms text to lowercase.
- PercentPipe Pipes
- WARNING: this pipe uses the Internationalization API. Therefore it is only reliable in Chrome and Opera browsers.
- Pipe Pipes
- Declare reusable pipe function.
- ReplacePipe Pipes
- Creates a new String with some or all of the matches of a pattern replaced by a replacement.
- SlicePipe Pipes
- Creates a new List or String containing a subset (slice) of the elements.
- UpperCasePipe Pipes
- Implements uppercase transforms to text.