SafeResourceUrl class Security
Represents a resource URL that has been marked as trusted and should bypass
resource URL sanitization (e.g., for <iframe src>).
Use SafeResourceUrl.trusted to create an instance from a trusted URL.
Constructors
- SafeResourceUrl.trusted(String url)
-
Creates a SafeResourceUrl instance from
urlthat will bypass sanitization.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
Returns the URL string.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited