SafeStyle class Security

Represents a style value that has been marked as trusted and should bypass style sanitization.

Use SafeStyle.trusted to create an instance from a trusted style string.

Constructors

SafeStyle.trusted(String style)
Creates a SafeStyle instance from style that will bypass sanitization.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
Returns the style string.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited