SafeUrl class Security
Represents a URL that has been marked as trusted and should bypass URL sanitization.
Use SafeUrl.trusted to create an instance from a trusted URL string.
Constructors
- SafeUrl.trusted(String url)
-
Creates a SafeUrl instance from
urlthat will bypass sanitization.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
Returns the URL string.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited