Testability class Testing
Provides testing hooks also accessible via JavaScript APIs in the browser.
Use whenStable to register callbacks that fire when the application becomes stable (no pending change detection cycles).
- Annotations
-
- @sealed
Constructors
- Testability(NgZone _ngZone)
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
whenStable(
void callback(bool didAsyncWork)) → void -
Registers
callbackto be invoked when change detection is completed.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited