directives property

List<Object> directives
final

A list of directives that can be used within this component's template.

Directives must be listed explicitly so the compiler knows which directives and components are available in the template scope.

Example

@Component(
  selector: 'my-comp',
  template: '<child-comp></child-comp>',
  directives: [ChildComponent],
)
class MyComponent {}

Implementation

final List<Object> directives;