pipes property

List<Object> pipes
final

A list of pipes that can be used within this component's template.

Pipes must be listed explicitly so the compiler knows which pipes are available in the template scope.

Example

@Component(
  selector: 'my-comp',
  template: '{{ birthday | myDatePipe }}',
  pipes: [MyDatePipe],
)
class MyComponent {}

Implementation

final List<Object> pipes;