Change Detection topic
Change detection APIs for controlling how and when AngularDart updates the view.
AngularDart uses an efficient change detection mechanism to keep the view
in sync with the model. You can customize this behavior per-component using
ChangeDetectionStrategy.
Classes
- ChangeDetectionStrategy Change Detection
- Describes within the change detector which strategy will be used the next time change detection is triggered.
- ChangeDetectorRef Change Detection
- Provides influence over how change detection should execute for a component.