Dependency Injection topic
Dependency injection system for managing services and their dependencies.
AngularDart uses a hierarchical injector system that allows you to configure services at the application, component, or directive level.
See also: Injector, Provider, Module.
Classes
- Host Dependency Injection
- Specifies that an injector should retrieve a dependency from any injector until reaching the closest host.
- Inject Dependency Injection
- A parameter metadata that specifies a dependency.
- Injectable Dependency Injection
- Compile-time metadata that marks a class Type or Function for injection.
- Injector Dependency Injection
- Support for imperatively loading dependency injected services at runtime.
- Module Dependency Injection
- Encapsulates a reusable set of dependency injection configurations.
-
MultiToken<
T extends Object> Dependency Injection -
A token representing multiple values of
Tfor dependency injection. -
OpaqueToken<
T extends Object> Dependency Injection - A token to be used instead of Type when configuring dependency injection.
- Optional Dependency Injection
- A parameter metadata that marks a dependency as optional.
-
Provider<
T extends Object> Dependency Injection -
Describes at compile-time how an
Injectorshould be configured. - Self Dependency Injection
- Specifies that an Injector should retrieve a dependency only from itself.
- SkipSelf Dependency Injection
- Specifies that the dependency resolution should start from the parent injector.