Security topic
Security utilities for safely handling HTML, URLs, and styles.
AngularDart has built-in support for sanitizing untrusted values to prevent
XSS attacks. See SafeHtml, SafeUrl, and SafeResourceUrl.
See the Security Guide.
Classes
- SafeHtml Security
-
Represents HTML content that has been marked as trusted and should bypass
sanitization when used with
[innerHtml]bindings. - SafeResourceUrl Security
-
Represents a resource URL that has been marked as trusted and should bypass
resource URL sanitization (e.g., for
<iframe src>). - SafeStyle Security
- Represents a style value that has been marked as trusted and should bypass style sanitization.
- SafeUrl Security
- Represents a URL that has been marked as trusted and should bypass URL sanitization.